@@ -124,22 +124,21 @@ static gboolean update_radio(radio_gui *data) {
 		perror("VIDIOCGAUDIO");
 
 	if (vid_aud.flags & VIDEO_AUDIO_MUTE) {
-		close(data->fd);		
+		close(data->fd);
 
 		// Radio is off.  Did I think it was on?
 		if (data->on) {
-			// manually clean up; radio_stop would call ioctl	
+			// manually clean up; radio_stop would call ioctl
 			if (data->show_signal)
 				gtk_widget_hide (data->signal_bar);
-			data->on = 0;
+			data->on = FALSE;
 		}
 	} else {
 		// Radio is on.  Did I think it was off?
 		if (!data->on) {
 			// manually clean up; radio_start would tune the radio
-			gtk_tooltips_enable (data->tooltips);			
-			
-			data->on = 1;
+			gtk_tooltips_enable (data->tooltips);
+			data->on = TRUE;
 		}
 
 		if (ioctl(data->fd, VIDIOCGFREQ, &freq)) {
@@ -152,10 +151,10 @@ static gboolean update_radio(radio_gui *data) {
 		freq /= data->freqfact;
 
 		data->freq = freq;
-	}	
+	}
 
 	update_label(data);
-	update_signal_bar(data);	
+	update_signal_bar(data);
 
 	return TRUE;
 }
@@ -682,21 +681,16 @@ free_presets (radio_gui *data)
 }
 
 static void
-plugin_free (radio_gui *data)
+radio_free (XfcePanelPlugin *plugin, radio_gui *data)
 {
 	if (data->on) radio_stop(data);
 	free_presets (data);
 	g_free (data);
 
-	/* TODO: check this
-+	
-+	// lex: I think this is necessary.
-+	if (data->signal_timeout_id)
-+		g_source_remove(data->signal_timeout_id);	
-+	if (data->radio_timeout_id)
-+		g_source_remove(data->radio_timeout_id);
-+	
- 	*/
+	if (data->signal_timeout_id)
+		g_source_remove(data->signal_timeout_id);
+	if (data->radio_timeout_id)
+		g_source_remove(data->radio_timeout_id);
 }
 
 static radio_gui *
@@ -911,7 +905,7 @@ radio_plugin_create_options (XfcePanelPlugin *plugin, radio_gui *data)
 	gtk_table_attach (GTK_TABLE (table), hbox, 1, 2, 2, 3, GTK_FILL,
 							GTK_FILL, 0, 0);
 
-	frequency_button = gtk_radio_button_new_with_label (NULL, 
+	frequency_button = gtk_radio_button_new_with_label (NULL,
 							_("frequency"));
 	gtk_widget_show (frequency_button);
 	gtk_box_pack_start (GTK_BOX (hbox), frequency_button, FALSE, FALSE, 0);
@@ -1063,7 +1057,7 @@ radio_plugin_construct (XfcePanelPlugin *plugin)
 			G_CALLBACK (radio_plugin_create_options), data);
 	g_signal_connect (plugin, "size-changed", G_CALLBACK
 						(radio_plugin_set_size), data);
-	g_signal_connect (plugin, "free-data", G_CALLBACK (plugin_free), data);
+	g_signal_connect (plugin, "free-data", G_CALLBACK (radio_free), data);
 	g_signal_connect (plugin, "save", G_CALLBACK (write_config), data);
 }
 
